summaryrefslogtreecommitdiffstats
path: root/chromium/ui/views/controls/table/table_utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/ui/views/controls/table/table_utils.h')
-rw-r--r--chromium/ui/views/controls/table/table_utils.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/chromium/ui/views/controls/table/table_utils.h b/chromium/ui/views/controls/table/table_utils.h
index 3c5d4c78175..ec387102e69 100644
--- a/chromium/ui/views/controls/table/table_utils.h
+++ b/chromium/ui/views/controls/table/table_utils.h
@@ -11,7 +11,7 @@
#include "ui/views/views_export.h"
namespace gfx {
-class Font;
+class FontList;
}
namespace views {
@@ -23,23 +23,23 @@ VIEWS_EXPORT extern const int kUnspecifiedColumnWidth;
// Returns the width needed to display the contents of the specified column.
// This is used internally by CalculateTableColumnSizes() and generally not
// useful by itself. |header_padding| is padding added to the header.
-VIEWS_EXPORT int WidthForContent(const gfx::Font& header_font,
- const gfx::Font& content_font,
+VIEWS_EXPORT int WidthForContent(const gfx::FontList& header_font_list,
+ const gfx::FontList& content_font_list,
int padding,
int header_padding,
const ui::TableColumn& column,
ui::TableModel* model);
// Determines the width for each of the specified columns. |width| is the width
// to fit the columns into. |header_font| the font used to draw the header and
// |content_font| the header used to draw the content. |padding| is extra
// horizontal spaced added to each cell, and |header_padding| added to the
// width needed for the header.
VIEWS_EXPORT std::vector<int> CalculateTableColumnSizes(
int width,
int first_column_padding,
- const gfx::Font& header_font,
- const gfx::Font& content_font,
+ const gfx::FontList& header_font_list,
+ const gfx::FontList& content_font_list,
int padding,
int header_padding,
const std::vector<ui::TableColumn>& columns,
@@ -23,23 +23,23 @@ VIEWS_EXPORT extern const int kUnspecifiedColumnWidth;
ui::TableModel* model);
// Determines the width for each of the specified columns. |width| is the width
-// to fit the columns into. |header_font| the font used to draw the header and
-// |content_font| the header used to draw the content. |padding| is extra
-// horizontal spaced added to each cell, and |header_padding| added to the
-// width needed for the header.
+// to fit the columns into. |header_font_list| the font list used to draw the
+// header and |content_font_list| the header used to draw the content. |padding|
+// is extra horizontal spaced added to each cell, and |header_padding| added to
+// the width needed for the header.
VIEWS_EXPORT std::vector<int> CalculateTableColumnSizes(
int width,